==> jc-1.4.0.tar.gz: java/beans/PropertyChangeEvent.h <==
// public class java.beans.PropertyChangeEvent

// class file dependencies
// @dep_class bf73c40f042d389a java_beans_PropertyChangeEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_java_beans_PropertyChangeEvent_H_
#define _JC_java_beans_PropertyChangeEvent_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_beans_PropertyChangeEvent$sub_refs	_jc_java_beans_PropertyChangeEvent$sub_refs;
typedef struct _jc_java_beans_PropertyChangeEvent$sub_nonrefs	_jc_java_beans_PropertyChangeEvent$sub_nonrefs;
typedef struct _jc_java_beans_PropertyChangeEvent$refs	_jc_java_beans_PropertyChangeEvent$refs;
typedef struct _jc_java_beans_PropertyChangeEvent$nonrefs	_jc_java_beans_PropertyChangeEvent$nonrefs;
typedef struct _jc_java_beans_PropertyChangeEvent$object	_jc_java_beans_PropertyChangeEvent$object;

typedef struct _jc_java_beans_PropertyChangeEvent$fields_struct	_jc_java_beans_PropertyChangeEvent$fields_struct;
typedef const struct _jc_java_beans_PropertyChangeEvent$vmethods	_jc_java_beans_PropertyChangeEvent$vmethods;
typedef const struct _jc_java_beans_PropertyChangeEvent$vtable	_jc_java_beans_PropertyChangeEvent$vtable;
typedef const struct _jc_java_beans_PropertyChangeEvent$vtype	_jc_java_beans_PropertyChangeEvent$vtype;

// Class fields structure
struct _jc_java_beans_PropertyChangeEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_beans_PropertyChangeEvent$fields_struct _jc_java_beans_PropertyChangeEvent$class_fields;

// Constructors
extern void _jc_java_beans_PropertyChangeEvent$method$_init$0e263b304a7cc0fb(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_beans_PropertyChangeEvent$method$getNewValue$3a6d0e39a264f181(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *);
extern struct _jc_java_lang_Object$object *_jc_java_beans_PropertyChangeEvent$method$getOldValue$4c8db6a01d524d71(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *);
extern struct _jc_java_lang_Object$object *_jc_java_beans_PropertyChangeEvent$method$getPropagationId$a0b527bdf4de5d30(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *);
extern struct _jc_java_lang_String$object *_jc_java_beans_PropertyChangeEvent$method$getPropertyName$3ce73dcd3d514390(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *);
extern struct _jc_java_beans_PropertyChangeEvent$object *_jc_java_beans_PropertyChangeEvent$method$rollback$7566aaf53588805e(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *);
extern void _jc_java_beans_PropertyChangeEvent$method$setPropagationId$647486cd275dfe67(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_beans_PropertyChangeEvent$method_info$getNewValue$3a6d0e39a264f181;
extern _jc_method _jc_java_beans_PropertyChangeEvent$method_info$getOldValue$4c8db6a01d524d71;
extern _jc_method _jc_java_beans_PropertyChangeEvent$method_info$getPropagationId$a0b527bdf4de5d30;
extern _jc_method _jc_java_beans_PropertyChangeEvent$method_info$getPropertyName$3ce73dcd3d514390;
extern _jc_method _jc_java_beans_PropertyChangeEvent$method_info$rollback$7566aaf53588805e;
extern _jc_method _jc_java_beans_PropertyChangeEvent$method_info$setPropagationId$647486cd275dfe67;

// Virtual methods structure
struct _jc_java_beans_PropertyChangeEvent$vmethods {
	struct _jc_java_lang_Object$object	*(*getNewValue$3a6d0e39a264f181)(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *);
	struct _jc_java_lang_Object$object	*(*getOldValue$4c8db6a01d524d71)(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *);
	struct _jc_java_lang_Object$object	*(*getPropagationId$a0b527bdf4de5d30)(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *);
	struct _jc_java_lang_String$object	*(*getPropertyName$3ce73dcd3d514390)(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *);
	struct _jc_java_beans_PropertyChangeEvent$object	*(*rollback$7566aaf53588805e)(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *);
	void	(*setPropagationId$647486cd275dfe67)(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_beans_PropertyChangeEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_beans_PropertyChangeEvent$vmethods	java_beans_PropertyChangeEvent;
};

// Vtype
struct _jc_java_beans_PropertyChangeEvent$vtype {
	_jc_type			type;
	_jc_java_beans_PropertyChangeEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_PropertyChangeEvent$sub_refs {
	struct _jc_java_lang_String$object	*propertyName;
	struct _jc_java_lang_Object$object	*newValue;
	struct _jc_java_lang_Object$object	*oldValue;
	struct _jc_java_lang_Object$object	*propagationId;
};

// Reference instance fields (object)
struct _jc_java_beans_PropertyChangeEvent$refs {
    _jc_java_beans_PropertyChangeEvent$sub_refs	java_beans_PropertyChangeEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_PropertyChangeEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_PropertyChangeEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_beans_PropertyChangeEvent$sub_nonrefs	java_beans_PropertyChangeEvent;
};

// Object instance structure
struct _jc_java_beans_PropertyChangeEvent$object {
	_jc_java_beans_PropertyChangeEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_PropertyChangeEvent$vtype	*vtype;
	_jc_java_beans_PropertyChangeEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_PropertyChangeEvent$vtype _jc_java_beans_PropertyChangeEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_PropertyChangeEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_PropertyChangeEvent$class_object;

#endif	/* _JC_java_beans_PropertyChangeEvent_H_ */

==> jc-1.4.6.tar.gz: java/beans/PropertyChangeEvent.h <==
// public class java.beans.PropertyChangeEvent

// class file dependencies
// @dep_class bf73c40f042d389a java_beans_PropertyChangeEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_java_beans_PropertyChangeEvent_H_
#define _JC_java_beans_PropertyChangeEvent_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_beans_PropertyChangeEvent$sub_refs	_jc_java_beans_PropertyChangeEvent$sub_refs;
typedef struct _jc_java_beans_PropertyChangeEvent$sub_nonrefs	_jc_java_beans_PropertyChangeEvent$sub_nonrefs;
typedef struct _jc_java_beans_PropertyChangeEvent$refs	_jc_java_beans_PropertyChangeEvent$refs;
typedef struct _jc_java_beans_PropertyChangeEvent$nonrefs	_jc_java_beans_PropertyChangeEvent$nonrefs;
typedef struct _jc_java_beans_PropertyChangeEvent$object	_jc_java_beans_PropertyChangeEvent$object;

typedef struct _jc_java_beans_PropertyChangeEvent$fields_struct	_jc_java_beans_PropertyChangeEvent$fields_struct;
typedef const struct _jc_java_beans_PropertyChangeEvent$vmethods	_jc_java_beans_PropertyChangeEvent$vmethods;
typedef const struct _jc_java_beans_PropertyChangeEvent$vtable	_jc_java_beans_PropertyChangeEvent$vtable;
typedef const struct _jc_java_beans_PropertyChangeEvent$vtype	_jc_java_beans_PropertyChangeEvent$vtype;

// Class fields structure
struct _jc_java_beans_PropertyChangeEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_beans_PropertyChangeEvent$fields_struct _jc_java_beans_PropertyChangeEvent$class_fields;

// Constructors
extern void _jc_java_beans_PropertyChangeEvent$method$_init$0e263b304a7cc0fb(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_beans_PropertyChangeEvent$method$getNewValue$3a6d0e39a264f181(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_beans_PropertyChangeEvent$method$getOldValue$4c8db6a01d524d71(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_beans_PropertyChangeEvent$method$getPropagationId$a0b527bdf4de5d30(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_beans_PropertyChangeEvent$method$getPropertyName$3ce73dcd3d514390(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_beans_PropertyChangeEvent$object *_jc_java_beans_PropertyChangeEvent$method$rollback$7566aaf53588805e(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_beans_PropertyChangeEvent$method$setPropagationId$647486cd275dfe67(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_beans_PropertyChangeEvent$method_info$getNewValue$3a6d0e39a264f181;
extern _jc_method _jc_java_beans_PropertyChangeEvent$method_info$getOldValue$4c8db6a01d524d71;
extern _jc_method _jc_java_beans_PropertyChangeEvent$method_info$getPropagationId$a0b527bdf4de5d30;
extern _jc_method _jc_java_beans_PropertyChangeEvent$method_info$getPropertyName$3ce73dcd3d514390;
extern _jc_method _jc_java_beans_PropertyChangeEvent$method_info$rollback$7566aaf53588805e;
extern _jc_method _jc_java_beans_PropertyChangeEvent$method_info$setPropagationId$647486cd275dfe67;

// Virtual methods structure
struct _jc_java_beans_PropertyChangeEvent$vmethods {
	struct _jc_java_lang_Object$object	*(*getNewValue$3a6d0e39a264f181)(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getOldValue$4c8db6a01d524d71)(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getPropagationId$a0b527bdf4de5d30)(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPropertyName$3ce73dcd3d514390)(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_beans_PropertyChangeEvent$object	*(*rollback$7566aaf53588805e)(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
	void	(*setPropagationId$647486cd275dfe67)(_jc_env *, struct _jc_java_beans_PropertyChangeEvent$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_beans_PropertyChangeEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_beans_PropertyChangeEvent$vmethods	java_beans_PropertyChangeEvent;
};

// Vtype
struct _jc_java_beans_PropertyChangeEvent$vtype {
	_jc_type			type;
	_jc_java_beans_PropertyChangeEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_PropertyChangeEvent$sub_refs {
	struct _jc_java_lang_String$object	*propertyName;
	struct _jc_java_lang_Object$object	*newValue;
	struct _jc_java_lang_Object$object	*oldValue;
	struct _jc_java_lang_Object$object	*propagationId;
};

// Reference instance fields (object)
struct _jc_java_beans_PropertyChangeEvent$refs {
    _jc_java_beans_PropertyChangeEvent$sub_refs	java_beans_PropertyChangeEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_PropertyChangeEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_PropertyChangeEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_beans_PropertyChangeEvent$sub_nonrefs	java_beans_PropertyChangeEvent;
};

// Object instance structure
struct _jc_java_beans_PropertyChangeEvent$object {
	_jc_java_beans_PropertyChangeEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_PropertyChangeEvent$vtype	*vtype;
	_jc_java_beans_PropertyChangeEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_PropertyChangeEvent$vtype _jc_java_beans_PropertyChangeEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_PropertyChangeEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_PropertyChangeEvent$class_object;

#endif	/* _JC_java_beans_PropertyChangeEvent_H_ */
